aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlex Auvolat <alex@adnab.me>2022-11-16 16:52:38 +0100
committerAlex Auvolat <alex@adnab.me>2022-11-16 16:52:38 +0100
commit78440a03d270eaacf68179dd79d5a016e45828ca (patch)
tree3a8f3fe125bd69b0704da2b2c3eb86c6489638f5
parent49b0dc2d5bfe9b92e6e02e6f0fa1076c4204f8b8 (diff)
downloadnixcfg-78440a03d270eaacf68179dd79d5a016e45828ca.tar.gz
nixcfg-78440a03d270eaacf68179dd79d5a016e45828ca.zip
add+cleanup config
-rw-r--r--cluster/staging/node/cariacou.nix9
1 files changed, 8 insertions, 1 deletions
diff --git a/cluster/staging/node/cariacou.nix b/cluster/staging/node/cariacou.nix
index 04e581d..818a88e 100644
--- a/cluster/staging/node/cariacou.nix
+++ b/cluster/staging/node/cariacou.nix
@@ -22,14 +22,21 @@
deuxfleurs.cluster_ip = "10.14.1.1";
deuxfleurs.is_raft_server = true;
- # experimental: nomad as root, to enable exec driver
+ # ----
+
+ # experimental: config for nomad nix driver
services.nomad.dropPrivileges = false;
services.nomad.extraPackages = [
pkgs.nix
+ pkgs.git
];
services.nomad.extraSettingsPlugins =
let nomad_driver_nix = import ./nomad-driver-nix.nix { inherit pkgs; };
in [ nomad_driver_nix ];
# the nix driver requires flakes to be enabled
nix.settings.experimental-features = [ "nix-command" "flakes" ];
+
+ # use our cache as additionnal substituer
+ nix.settings.substituers = [ "https://nix.web.deuxfleurs.fr" ];
+ nix.settings.trusted-public-keys = [ "nix.web.deuxfleurs.fr:eTGL6kvaQn6cDR/F9lDYUIP9nCVR/kkshYfLDJf1yKs=" ];
}